@@ -1,46 +1,3 @@
-//! Contentful API Rust Client 
-//! 
-//! ## Usage example
-//! 
-//! ```rust
-//! let contentful_client = ContentfulClient::new("<access_token>", "<space_id>");
-//! let product = contentful_client.get_entry::<Product>("<entry_id>").await?;
-//! 
-//! if let Some(product) = product {
-//!     let name = product.name;
-//!     //..
-//! }
-//! ```
-//! For more examples, please see the [tests] folder
-//! 
-//! ## Querying for content
-//! 
-//! ### Get a single entry
-//! 
-//! To get a single entry use the get_entry<T> method.
-//! 
-//! ```rust
-//! let product = contentful_client.get_entry::<Product>("<entry_id>").await?;
-//! 
-//! ```
-//! 
-//! ### Get multiple entries
-//! 
-//! There are several methods to retrieve multiple entries available in the SDK.
-//! 
-//! #### Get and filter entries
-//! 
-//! ```rust
-//! let builder = QueryBuilder::new()
-//!         .content_type_is("product")
-//!         .field_equals("fields.name", name);
-//! let products = contentful_client
-//!         .get_entries::<Product>(Some(builder))
-//!         .await?
-//! ```
-//! 
-//! [tests]: https://github.com/sajuthankappan/contentful-rs/tree/master/tests
-
 use crate::query_builder::QueryBuilder;
 use crate::{http_client, models::Entry};
 use serde::{Deserialize, Serialize};
@@ -225,7 +182,10 @@ impl ContentfulClient {
         includes: &Value,
     ) -> Result<(), Box<dyn std::error::Error>> {
         let sys_type = value["sys"]["type"].clone();
-        if sys_type == "Entry" {
+
+        if sys_type == Value::Null {
+            // Do nothing as this field is meant to be raw JSON.
+        } else if sys_type == "Entry" {
             self.resolve_entry(value, &includes)?;
         //*value = value["fields"].clone();
         } else if sys_type == "Link" {
